@@ -1,14 +1,28 @@
 # -*- coding: utf-8 -*-
 
-# ########################## Copyrights and license ############################
+############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
+# Copyright 2013 David Farr <david.farr@sap.com>                               #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2015 Ed Holland <eholland@alertlogic.com>                          #
+# Copyright 2016 John Eskew <jeskew@edx.org>                                   #
+# Copyright 2016 Matthew Neal <meneal@matthews-mbp.raleigh.ibm.com>            #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2016 Sam Corbett <sam.corbett@cloudsoftcorp.com>                   #
+# Copyright 2017 Aaron Levine <allevin@sandia.gov>                             #
+# Copyright 2017 Nicolas Agustín Torres <nicolastrres@gmail.com>              #
+# Copyright 2018 Hayden Fuss <wifu1234@gmail.com>                              #
+# Copyright 2018 Shinichi TAMURA <shnch.tmr@gmail.com>                         #
+# Copyright 2018 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
-# http://pygithub.github.io/PyGithub/v1/index.html                             #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -23,12 +37,13 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-# ##############################################################################
+################################################################################
 
 from AuthenticatedUser import *
 from Authentication import *
 from Authorization import *
 from Branch import *
+from BranchProtection import *
 from Commit import *
 from CommitCombinedStatus import *
 from CommitComment import *
@@ -43,12 +58,15 @@ from GitCommit import *
 from Github_ import *
 from GitRef import *
 from GitRelease import *
+from GitReleaseAsset import *
 from GitTag import *
 from GitTree import *
 from Hook import *
 from Issue import *
 from IssueComment import *
+from Reaction import *
 from IssueEvent import *
+from License import *
 from Label import *
 from Milestone import *
 from NamedUser import *
@@ -57,10 +75,14 @@ from OrganizationHasInMembers import *
 from Organization import *
 from PullRequest import *
 from PullRequestComment import *
+from PullRequestReview import *
 from PullRequestFile import *
 from RateLimiting import *
 from Repository import *
 from RepositoryKey import *
+from RequiredPullRequestReviews import *
+from RequiredStatusChecks import *
+from SourceImport import *
 from Status import *
 from Tag import *
 from Team import *
@@ -95,3 +117,4 @@ from Issue214 import *
 from Issue216 import *
 from Issue278 import *
 from Issue494 import *
+from Issue572 import *
